/************************************************************* C HEADER ***
 * JBA International, plc Confidential
 * (C) Copyright JBA International, plc, 1993.
 *-------------------------------------------------------------------------
 * $Header: $
 *
 * Project:          GUIDE       - Guidelines
 *
 * Component:        PICTURE      - Picture Controls
 *
 * File Name:        PICTURE.H
 *
 * Original Author:  Greg Jones
 *
 * Description:      Guidelines Header File for the Picture Controls
 *
 * $Log: $
 * 
 *************************************************************************/
#ifndef   H_PICTURE
#define   H_PICTURE

/**************************************************************************
 * Custom control window Class and Name
 *************************************************************************/
#define  WT_PICPANEL       "Picture Panel"
#define  WT_PICSET         "Set Button"
#define  WT_PICTOGGLE      "Toggle Button"
#define  WT_PICMSTATE      "MultiState Button"
#define  WT_PICANIMATE     "Animated Button"
#define  WT_PICBUTTON      "Picture Button"
#define  WC_GUIPICBUTTON   "GUIPICBUTTON"

/**************************************************************************
 * Picture Panel and Button Styles.
 *************************************************************************/
#define  PCS_PICBUTTON           0x00000000L          /* Normal Push Button         */
#define  PCS_TOGGLE              0x00000001L          /* Toggle Button              */
#define  PCS_MULTISTATE          0x00000002L          /* Multistate Button          */
#define  PCS_SET                 0x00000003L          /* Button Set                 */
#define  PCS_PANEL               0x00000004L          /* Picture Panel              */
#define  PCS_ANIMATED            0x00000005L          /* Animated Push Button       */
#define  PCS_PRIMARYSTYLES       0x00000007L          /* Mask for Primary Styles    */

#define  PCS_DEFAULT             0x00000008L          /* Default Button             */
#define  PCS_NOPOINTERFOCUS      0x00000010L          /* No Pointer Focus           */

#define  PCS_AUTOSIZEWIN         0x00000020L          /* Auto Size Window           */
#define  PCS_AUTOSIZEPAR         0x00000040L          /* Auto Size To Parent        */

#define  PCS_ALIGNLEFT           0x00000000L          /* Left Align Text            */
#define  PCS_ALIGNCENTER         0x00000100L          /* Center Align Text          */
#define  PCS_ALIGNRIGHT          0x00000200L          /* Right Align Text           */
#define  PCS_ALIGNTOP            0x00000000L          /* Top Align Text             */
#define  PCS_ALIGNMIDDLE         0x00000400L          /* Middle Align Text          */
#define  PCS_ALIGNBOTTOM         0x00000800L          /* Bottom Align Text          */
#define  PCS_TEXTOUT             0x00001000L          /* Text Outside Button        */

#define  PCS_ZERODISABLED        0x00002000L          /* 0'th Picture is Disabled   */

#define  PCS_SYSCOMMAND          0x00004000L          /* System Command Message     */
#define  PCS_HELP                0x00008000L          /* Help Request               */

/*
 * Picture Drawing Flags - Set at design time and runtime
 */
#define  PCS_NORMAL              0x00000001L          /* Normal Picture             */
#define  PCS_INVERT              0x00000002L          /* Inverted Picture           */
#define  PCS_HALFTONE            0x00000004L          /* Halftone Picture           */
#define  PCS_TILED               0x00000008L          /* Tiled Picture              */
#define  PCS_STRETCH             0x00000010L          /* Stretch Picture            */
#define  PCS_STATE               0x00000020L          /* Picture is a State         */

/**************************************************************************
 * Picture Panel and Button Window Property IDs
 *************************************************************************/
#define  WPID_PICBORDER          WPID_USER + 0     /* Border Property            */
#define  WPID_PICLINEWIDTH       WPID_USER + 1     /* LineWidth Property         */
#define  WPID_PICELEVATION       WPID_USER + 2     /* Elevation Property         */
#define  WPID_PICFILL            WPID_USER + 3     /* Fill Property              */
#define  WPID_PICXROUND          WPID_USER + 4     /* XRound Property            */
#define  WPID_PICYROUND          WPID_USER + 5     /* YRound Property            */
#define  WPID_PICINTERVAL        WPID_USER + 6     /* Interval Property          */
#define  WPID_PICNUMPICS         WPID_USER + 7     /* NumPictures' Property      */
#define  WPID_PICHEIGHT          WPID_USER + 8     /* PicHeight Property         */
#define  WPID_PICWIDTH           WPID_USER + 9     /* PicWidth Property          */
#define  WPID_PICTURES           WPID_USER + 10    /* Pictures Property          */

/* Runtime-only properties */
#define  WPID_PICINDEX           WPID_USER + 11    /* Index Property             */
#define  WPID_PICXOFFSET         WPID_USER + 12    /* XOffset Property           */
#define  WPID_PICYOFFSET         WPID_USER + 13    /* YOffset Property           */
#define  WPID_PICNUMSTATE        WPID_USER + 14    /* NumStates Property         */
#define  WPID_PICSTATE           WPID_USER + 15    /* State Property             */

/**************************************************************************
 * Limits of Values for various properties
 *************************************************************************/
#define  MIN_BORDERSTYLE         0                 /* Minimum Border Style       */
#define  MAX_BORDERSTYLE         8                 /* Maximum Border Style       */

#define  MIN_FILLSTYLE           0                 /* Minimum Fill Style         */
#define  MAX_FILLSTYLE           18                /* Maximum Fill Style         */

#define  MIN_ELEVATION           (-32768)          /* Minimum Elevation          */
#define  MAX_ELEVATION             32767           /* Maximum Elevation          */

#define  MIN_LINEWIDTH           0                 /* Minimum Line Width         */
#define  MAX_LINEWIDTH           65535             /* Maximum Line Width         */

#define  MIN_PICXROUND           0                 /* Minimum X Corner Rounding  */
#define  MAX_PICXROUND           65535             /* Maximum X Corner Rounding  */

#define  MIN_PICYROUND           0                 /* Minimum Y Corner Rounding  */
#define  MAX_PICYROUND           65535             /* Maximum Y Corner Rounding  */

#define  MIN_INTERVAL            0                 /* Minimum Interval           */
#define  MAX_INTERVAL            65535             /* Maximum Interval           */

/**************************************************************************
 * Additional Window Messages
 *************************************************************************/
#define  PCM_SETPICTURE          WM_GUIUSER + 0    /* Set Picture Data           */
#define  PCM_QUERYPICTURE        WM_GUIUSER + 1    /* Query Picture Data         */

#define  PCM_SETDRAWMODE         WM_GUIUSER + 2    /* Set Picture Data           */
#define  PCM_QUERYDRAWMODE       WM_GUIUSER + 3    /* Query Picture Data         */

/**************************************************************************
 * Additional Notification Codes
 *************************************************************************/
#define  PCN_CHANGE              1                 /* Picture Index has changed  */
#define  PCN_STATE               2                 /* Picture State has changed  */

/**************************************************************************
 * Function Prototypes
 *************************************************************************/
VOID GuiPictureRegister (HAB hab);
MRESULT APIENTRY GuiPictureCtlProc (HWND, ULONG, MPARAM, MPARAM);

Image GuiPictureGetImage (WINDOW *pWin, USHORT usImageIndex);
BOOL GuiPictureSetImage (WINDOW *pWin, USHORT usImageIndex, Image NewImage);

USHORT GuiPictureGetDrawMode (WINDOW *pWin, USHORT usImageIndex);
BOOL GuiPictureSetDrawMode (WINDOW *pWin, USHORT usImageIndex, USHORT usDrawMode);

#endif

/**************************************************************************
 * End of picture.h
 *************************************************************************/

